==> arrow-docs-0.8.0-sources.jar: com/example/domain/Employees$$optics.kt <==
package `com`.`example`.`domain`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `com`.`example`.`domain`.`Employees`.Companion.iso: arrow.optics.Iso<`com`.`example`.`domain`.`Employees`, `arrow`.`data`.`ListK`<`com`.`example`.`domain`.`Employee`>> inline get()= arrow.optics.Iso(
  get = { employees: `com`.`example`.`domain`.`Employees` -> employees.employees },
  reverseGet = { `com`.`example`.`domain`.`Employees`(it) }
)

inline val `com`.`example`.`domain`.`Employees`.Companion.employees: arrow.optics.Lens<`com`.`example`.`domain`.`Employees`, `arrow`.`data`.`ListK`<`com`.`example`.`domain`.`Employee`>> inline get()= arrow.optics.Lens(
  get = { employees: `com`.`example`.`domain`.`Employees` -> employees.`employees` },
  set = { value: `arrow`.`data`.`ListK`<`com`.`example`.`domain`.`Employee`> ->
    { employees: `com`.`example`.`domain`.`Employees` ->
      employees.copy(`employees` = value)
    }
  }
)



inline val <S> arrow.optics.Iso<S, `com`.`example`.`domain`.`Employees`>.employees: arrow.optics.Lens<S, `arrow`.`data`.`ListK`<`com`.`example`.`domain`.`Employee`>> inline get() = this + `com`.`example`.`domain`.`Employees`.employees
inline val <S> arrow.optics.Lens<S, `com`.`example`.`domain`.`Employees`>.employees: arrow.optics.Lens<S, `arrow`.`data`.`ListK`<`com`.`example`.`domain`.`Employee`>> inline get() = this + `com`.`example`.`domain`.`Employees`.employees
inline val <S> arrow.optics.Optional<S, `com`.`example`.`domain`.`Employees`>.employees: arrow.optics.Optional<S, `arrow`.`data`.`ListK`<`com`.`example`.`domain`.`Employee`>> inline get() = this + `com`.`example`.`domain`.`Employees`.employees
inline val <S> arrow.optics.Prism<S, `com`.`example`.`domain`.`Employees`>.employees: arrow.optics.Optional<S, `arrow`.`data`.`ListK`<`com`.`example`.`domain`.`Employee`>> inline get() = this + `com`.`example`.`domain`.`Employees`.employees
inline val <S> arrow.optics.Getter<S, `com`.`example`.`domain`.`Employees`>.employees: arrow.optics.Getter<S, `arrow`.`data`.`ListK`<`com`.`example`.`domain`.`Employee`>> inline get() = this + `com`.`example`.`domain`.`Employees`.employees
inline val <S> arrow.optics.Setter<S, `com`.`example`.`domain`.`Employees`>.employees: arrow.optics.Setter<S, `arrow`.`data`.`ListK`<`com`.`example`.`domain`.`Employee`>> inline get() = this + `com`.`example`.`domain`.`Employees`.employees
inline val <S> arrow.optics.Traversal<S, `com`.`example`.`domain`.`Employees`>.employees: arrow.optics.Traversal<S, `arrow`.`data`.`ListK`<`com`.`example`.`domain`.`Employee`>> inline get() = this + `com`.`example`.`domain`.`Employees`.employees
inline val <S> arrow.optics.Fold<S, `com`.`example`.`domain`.`Employees`>.employees: arrow.optics.Fold<S, `arrow`.`data`.`ListK`<`com`.`example`.`domain`.`Employee`>> inline get() = this + `com`.`example`.`domain`.`Employees`.employees

==> arrow-docs-0.9.0-sources.jar: com/example/domain/Employees$$optics.kt <==
package `com`.`example`.`domain`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `com`.`example`.`domain`.`Employees`.Companion.iso: arrow.optics.Iso<`com`.`example`.`domain`.`Employees`, `arrow`.`data`.`ListK`<`com`.`example`.`domain`.`Employee`>> inline get()= arrow.optics.Iso(
  get = { employees: `com`.`example`.`domain`.`Employees` -> employees.employees },
  reverseGet = { `com`.`example`.`domain`.`Employees`(it) }
)

inline val `com`.`example`.`domain`.`Employees`.Companion.employees: arrow.optics.Lens<`com`.`example`.`domain`.`Employees`, `arrow`.`data`.`ListK`<`com`.`example`.`domain`.`Employee`>> inline get()= arrow.optics.Lens(
  get = { employees: `com`.`example`.`domain`.`Employees` -> employees.`employees` },
  set = { employees: `com`.`example`.`domain`.`Employees`, value: `arrow`.`data`.`ListK`<`com`.`example`.`domain`.`Employee`> -> employees.copy(`employees` = value) }
)



inline val <S> arrow.optics.Iso<S, `com`.`example`.`domain`.`Employees`>.employees: arrow.optics.Lens<S, `arrow`.`data`.`ListK`<`com`.`example`.`domain`.`Employee`>> inline get() = this + `com`.`example`.`domain`.`Employees`.employees
inline val <S> arrow.optics.Lens<S, `com`.`example`.`domain`.`Employees`>.employees: arrow.optics.Lens<S, `arrow`.`data`.`ListK`<`com`.`example`.`domain`.`Employee`>> inline get() = this + `com`.`example`.`domain`.`Employees`.employees
inline val <S> arrow.optics.Optional<S, `com`.`example`.`domain`.`Employees`>.employees: arrow.optics.Optional<S, `arrow`.`data`.`ListK`<`com`.`example`.`domain`.`Employee`>> inline get() = this + `com`.`example`.`domain`.`Employees`.employees
inline val <S> arrow.optics.Prism<S, `com`.`example`.`domain`.`Employees`>.employees: arrow.optics.Optional<S, `arrow`.`data`.`ListK`<`com`.`example`.`domain`.`Employee`>> inline get() = this + `com`.`example`.`domain`.`Employees`.employees
inline val <S> arrow.optics.Getter<S, `com`.`example`.`domain`.`Employees`>.employees: arrow.optics.Getter<S, `arrow`.`data`.`ListK`<`com`.`example`.`domain`.`Employee`>> inline get() = this + `com`.`example`.`domain`.`Employees`.employees
inline val <S> arrow.optics.Setter<S, `com`.`example`.`domain`.`Employees`>.employees: arrow.optics.Setter<S, `arrow`.`data`.`ListK`<`com`.`example`.`domain`.`Employee`>> inline get() = this + `com`.`example`.`domain`.`Employees`.employees
inline val <S> arrow.optics.Traversal<S, `com`.`example`.`domain`.`Employees`>.employees: arrow.optics.Traversal<S, `arrow`.`data`.`ListK`<`com`.`example`.`domain`.`Employee`>> inline get() = this + `com`.`example`.`domain`.`Employees`.employees
inline val <S> arrow.optics.Fold<S, `com`.`example`.`domain`.`Employees`>.employees: arrow.optics.Fold<S, `arrow`.`data`.`ListK`<`com`.`example`.`domain`.`Employee`>> inline get() = this + `com`.`example`.`domain`.`Employees`.employees
